#ifndef zetsubou_h
#define zetsubou_h

#include <iostream>
#include <iomanip>
#include <fstream>
#include <sstream>
#include <string>
#include <cstdio>
#include <cstring>
#include <cstdlib>
#include <cctype>

#include <TROOT.h>
#include <TStyle.h>
#include <TObject.h>
#include <TApplication.h>
#include <TBranch.h>
#include <TSpectrum.h>
#include <TCanvas.h>
#include <TString.h>
#include <TTree.h>
#include <TPad.h>
#include <TH1.h>
#include <TH2.h>
#include <TF1.h>
#include <TText.h>
#include <TPaveText.h>
#include <TMath.h>
#include <TRandom3.h>

#define HIST 1
#define SCAT 0

class zetsubou : public TObject
{
  public:
  zetsubou();//Constructor
  ~zetsubou();//Destructor

  bool MakeTree(const char *filename);//for getting data and making tree
  bool MakeCanvas(const char *name,Int_t i);//making a canvas corresponding histname or scatname
  void SetHistStyle();//set hist style
  void SetScatStyle();//set scat style 

  //drawing hist and scat
  TH1D *DrawHist(const char *filename,const char *title,const char *type,const char *histname,Int_t nbin,Double_t xmin,Double_t xmax,Int_t cutmin,Int_t cutmax);
  TH1D *DrawHist(const char *filename,const char *type,const char *histname,Int_t nbin,Double_t xmin,Double_t xmax,Int_t cutmin,Int_t cutmax);
  TH1D *DrawHist(const char *filename,const char *title,const char *type,const char *histname,Int_t nbin,Double_t xmin,Double_t xmax);
  TH1D *DrawHist(const char *filename,const char *type,const char *histname,Int_t nbin,Double_t xmin,Double_t xmax);
  TH1D *HistCut(Double_t X1,Double_t Y1,Double_t X2,Double_t Y2,Double_t X3,Double_t Y3,Double_t X4,Double_t Y4);
  
  TH2D *DrawScat(const char *filename,const char *title,const char *scatname);
  TH2D *DrawScat(const char *filename,const char *scatname);
  TH2D *DrawScat(const char *filename,const char *title,const char *scatname,Int_t xmin, Int_t xmax,Int_t ymin,Int_t ymax);
  TH2D *DrawScat(const char *filename,const char *scatname,Int_t xmin, Int_t xmax,Int_t ymin,Int_t ymax);  
  //fitting hist
  TF1 *gfit(Double_t xmin,Double_t xmax);
  TF1 *gfit(Double_t xmin,Double_t xmax,Double_t height,Double_t mean,Double_t sigma);
  TF1 *gfit(Double_t xmin,Double_t xmax,Double_t height,Double_t mean,Double_t sigma,Double_t katamuki, Double_t seppen);
  TF1 *gfit(Double_t xmin,Double_t xmax,Double_t height1,Double_t mean1,Double_t sigma1,Double_t height2, Double_t mean2, Double_t sigma2);
  TF1 *gfit(Double_t xmin,Double_t xmax,Double_t height1,Double_t mean1,Double_t sigma1,Double_t height2, Double_t mean2, Double_t sigma2,Double_t katamuki ,Double_t seppen);
  TF1 *gfit(Double_t xmin,Double_t xmax,Double_t height1,Double_t mean1,Double_t sigma1,Double_t height2, Double_t mean2, Double_t sigma2,Double_t height3,Double_t mean3,Double_t sigma3);
  TF1 *gfit(Double_t xmin,Double_t xmax,Double_t height1,Double_t mean1,Double_t sigma1,Double_t height2, Double_t mean2, Double_t sigma2,Double_t height3,Double_t mean3,Double_t sigma3,Double_t katamuki ,Double_t seppen);
  TF1 *lgfit(Double_t xmin,Double_t xmax,Double_t width,Double_t mp,Double_t area,Double_t gsigma);
  
  //after fitting, you can set limits of parameters
  TF1 *SetLimit(Int_t i,Double_t parmin,Double_t parmax);
  TF1 *SetLimit(const char *parname,Double_t parmin,Double_t parmax);

  //Searching Peaks Automatically by using TSpectrum class
  TSpectrum *Tspfit(Double_t xmin,Double_t xmax);
  TSpectrum *Tspfit(Double_t xmin,Double_t xmax,Double_t threshold);
  TSpectrum *Tspfit(Double_t xmin,Double_t xmax,Double_t threshold,Double_t resolution);
  
  TPaveText *MakeTextBox(Int_t parnum,Int_t parN);  

  inline TTree *GetTree() { return tr;}; //return pointer to current tree
 
  private:
  
  std::string currentfname;//input current filename 
  TTree *tr;
  TH1D  *hist;
  TH2D  *scat;
  TCanvas *canvas;
  TSpectrum *Tsp;
  TPaveText *tpt;
  
  TF1 *func;//fit function
  Int_t fitlinecolor;//fitlinecolor   
  
  Int_t Hist_canvas_length;
  Int_t Hist_canvas_width;
  Int_t Scat_canvas_length;
  Int_t Scat_canvas_width;

  Bool_t whichstyle;//HistStyle = 1 ,ScatStyle=0  
  
  ClassDef(zetsubou,1)//(ClassName,ClassVersionID) ClassVersionID should be >=1 

};

#endif //zetsubou.h
